The attached patch solves the <https://fedorahosted.org/freeipa/ticket/3959> 
ticket.

Veronika Kabatova
From 70abe5901c15e71735a0e4e26ea90334b233135b Mon Sep 17 00:00:00 2001
From: Veronika Kabatova <vkaba...@redhat.com>
Date: Thu, 9 Jul 2015 13:22:24 +0200
Subject: [PATCH] Enhance the DNSNotARecordError message

Enhance the DNSNotARecordError message as proposed in ticket #3959. User
is now suggested to use --force option.

https://fedorahosted.org/freeipa/ticket/3959
---
 ipalib/errors.py | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/ipalib/errors.py b/ipalib/errors.py
index 63ec22269467b769d276c443f6b3dbed38cd766e..d874e68829e1a5491dec402d5976c3adfa556e84 100644
--- a/ipalib/errors.py
+++ b/ipalib/errors.py
@@ -1142,12 +1142,14 @@ class DNSNotARecordError(ExecutionError):
     >>> raise DNSNotARecordError()
     Traceback (most recent call last):
       ...
     DNSNotARecordError: Host does not have corresponding DNS A/AAAA record
 
     """
 
     errno = 4019
-    format = _('Host does not have corresponding DNS A/AAAA record')
+    format = _('Host does not have corresponding DNS A/AAAA record, use'
+               ' --force to continue anyway')
 
 class ManagedGroupError(ExecutionError):
     """
@@ -1142,12 +1142,14 @@ class DNSNotARecordError(ExecutionError):
     Traceback (most recent call last):
       ...
-    DNSNotARecordError: Host does not have corresponding DNS A/AAAA record
+    DNSNotARecordError: Host does not have corresponding DNS A/AAAA record,
+    use --force to continue anyway
 
     """
-- 
2.4.3

-- 
Manage your subscription for the Freeipa-devel mailing list:
https://www.redhat.com/mailman/listinfo/freeipa-devel
Contribute to FreeIPA: http://www.freeipa.org/page/Contribute/Code

Reply via email to